@@ -1,6 +1,9 @@
 from sklearn.datasets import make_blobs
+from sklearn.model_selection import train_test_split
 import matplotlib.pyplot as plt
 
+import numpy as np
+
 def generate_synthetic_data(n_dim: int, n_clusters: int, n_samples: int) -> tuple:
     """
     Function to generate synthetic data to test the algorithms.
@@ -8,15 +11,14 @@ def generate_synthetic_data(n_dim: int, n_clusters: int, n_samples: int) -> tupl
     Return:
         tuple: containing the set of training and test values, with their associated labels
     """
-    random_state = 42
 
     X, y = make_blobs(n_samples=n_samples, 
                     n_features=n_dim, 
-                    centers=n_clusters, 
-                    random_state=random_state)
+                    centers=n_clusters)
 
-    # We create a breakpoint in the dataset to divide it and obtain a training set and a test set
-    breakpoint = n_samples * 3 // 4
+    train_X, test_X, train_y, test_y = train_test_split(X, y, test_size=0.2)
+    train_X = np.array(train_X) - train_X.min()
+    test_X = np.array(test_X) - test_X.min()
 
     # (training, test)
-    return X[:breakpoint], y[:breakpoint], X[breakpoint:], y[breakpoint:]
\ No newline at end of file
+    return train_X, train_y, test_X, test_y
\ No newline at end of file
